# Changelog

## [0.9.0](https://github.com/jbussdieker/bussdcc-framework/compare/v0.8.0...v0.9.0) (2026-03-04)


### Features

* **core:** improve error handling and remove redundant fields ([a70c4de](https://github.com/jbussdieker/bussdcc-framework/commit/a70c4dea655569aade8e8523118cfac6f3cfe147))

## [0.8.0](https://github.com/jbussdieker/bussdcc-framework/compare/v0.7.0...v0.8.0) (2026-03-04)


### Features

* **dependencies:** update bussdcc to version 0.29.0 ([57b598b](https://github.com/jbussdieker/bussdcc-framework/commit/57b598bb6ad537ed8f6cac79463dc3e48de082c5))

## [0.7.0](https://github.com/jbussdieker/bussdcc-framework/compare/v0.6.0...v0.7.0) (2026-03-03)


### Features

* **dependencies:** update bussdcc to version 0.28.0 ([a37f917](https://github.com/jbussdieker/bussdcc-framework/commit/a37f917ad7b0c112bbc5848f29ea827a77ce58df))

## [0.6.0](https://github.com/jbussdieker/bussdcc-framework/compare/v0.5.1...v0.6.0) (2026-03-03)


### Features

* **message:** enhance message handling and update dependencies ([a9d8ac7](https://github.com/jbussdieker/bussdcc-framework/commit/a9d8ac7ae22c308e5599d8ffd3db961554192777))

## [0.5.1](https://github.com/jbussdieker/bussdcc-framework/compare/v0.5.0...v0.5.1) (2026-03-02)


### Bug Fixes

* **web:** import `emit` function from the `context` module ([e86318d](https://github.com/jbussdieker/bussdcc-framework/commit/e86318d94fde86010f836d0551e56715d9bf9a20))

## [0.5.0](https://github.com/jbussdieker/bussdcc-framework/compare/v0.4.0...v0.5.0) (2026-03-02)


### Features

* **web:** add context management and message emission ([af8caab](https://github.com/jbussdieker/bussdcc-framework/commit/af8caab488d6e206520e1ec518f6a7ddf744848d))

## [0.4.0](https://github.com/jbussdieker/bussdcc-framework/compare/v0.3.0...v0.4.0) (2026-03-01)


### Features

* **bussdcc_framework:** rename events to message and update dependencies ([d98f33c](https://github.com/jbussdieker/bussdcc-framework/commit/d98f33c02140179a8e3f206867c293d07ea91058))

## [0.3.0](https://github.com/jbussdieker/bussdcc-framework/compare/v0.2.2...v0.3.0) (2026-03-01)


### Features

* **bussdcc_framework:** update event handling and dependencies ([20ec215](https://github.com/jbussdieker/bussdcc-framework/commit/20ec2159b167c1cfeef15c05a4d6754396203958))

## [0.2.2](https://github.com/jbussdieker/bussdcc-framework/compare/v0.2.1...v0.2.2) (2026-03-01)


### Bug Fixes

* **web:** update context processor and remove abstract methods ([8825418](https://github.com/jbussdieker/bussdcc-framework/commit/882541877ccc0e905af1ea205fef45fe1571e37e))

## [0.2.1](https://github.com/jbussdieker/bussdcc-framework/compare/v0.2.0...v0.2.1) (2026-03-01)


### Bug Fixes

* **bussdcc_framework:** add py.typed file ([93501a4](https://github.com/jbussdieker/bussdcc-framework/commit/93501a40be3b83383036ef0606bf9f19586b12a9))

## [0.2.0](https://github.com/jbussdieker/bussdcc-framework/compare/v0.1.0...v0.2.0) (2026-03-01)


### Features

* **web:** enhance Flask app creation and remove templates ([c974721](https://github.com/jbussdieker/bussdcc-framework/commit/c974721c78d07f17247a25a0d23faad1cb2a566f))

## 0.1.0 (2026-03-01)


### Features

* initial commit ([0c837b7](https://github.com/jbussdieker/bussdcc-framework/commit/0c837b7021923a01c4782e17b28693d0133e6c96))
